@@ -13,8 +13,8 @@ subroutine fft_read_name()
   namelist /input /nxi, nyi, hxnt, hynt, nt, Lx, Ly, dt,  &
   &                dmpstp, ininame, inix, iniy, iniz, inixd, iniyd,  &
   &                foname, time_flag, nu, flag_fric, mu,  &
-  &                flag_stretch, force_type, sth_fname, sth_vname, zetam,  &
-  &                sth_thres_zeta, cent_lat
+  &                flag_stretch, force_type, force_wn, force_kr, sth_fname, sth_vname,  &
+  &                zetam, sth_thres_zeta, cent_lat, tcx, tcy
   namelist /restart /resopt, resfname, restp
   read(5,nml=input)
   read(5,nml=restart)
@@ -38,8 +38,8 @@ subroutine fft_read_name_isp()
   &                nt, Lx, Ly, dt,  &
   &                dmpstp, ininame, inix, iniy, iniz, inixd, iniyd,  &
   &                foname, time_flag, nu, flag_fric, mu,  &
-  &                flag_stretch, force_type, sth_fname, sth_vname, zetam,  &
-  &                sth_thres_zeta, cent_lat
+  &                flag_stretch, force_type, force_wn, force_kr, sth_fname, sth_vname,  &
+  &                zetam, sth_thres_zeta, cent_lat, tcx, tcy
   namelist /restart /resopt, resfname, restp
   read(5,nml=input)
   read(5,nml=restart)
