@@ -39,6 +39,9 @@ subroutine fft_saveval_allocate()
   allocate(cr_isp(jynt,jxnt),stat=err)
   allocate(zinit_isp(jynt,jxnt),stat=err)
 
+  allocate(dmp_stretchk(kxnt,kynt),stat=err)
+  allocate(dmp_advectk(kxnt,kynt),stat=err)
+
   if(err/=0)then
      write(*,*) "*** ERROR (fft_saveval_allocate) *** : cannot allocate."
      stop
