@@ -1,7 +1,7 @@
 module time_scheme
-! ֥ऴȤ˷׻Ԥ⥸塼
-! force_solv Ƿ׻ͤ򥹥˹碌Ƴ꿶,
-! ֥ƥåפȯŸ.
+! 時間スキームごとに計算を行うモジュール
+! force_solv で計算した強制項の値をスキームに合わせて割り振り,
+! 時間ステップを発展させる.
   use Derivation
   use Ellip_Slv
   use max_min
@@ -21,15 +21,15 @@ contains
 subroutine time_schematic( step )
 
   implicit none
-  integer, intent(in) :: step  ! ॹƥåֹ
+  integer, intent(in) :: step  ! タイムステップ番号
   integer :: ct, i, j
 
-!-- ڥȥѿʬ
+!-- スペクトル変数を実部・虚部に分割
 
   select case (time_flag(1:1))
-  case ('1')  ! RK4 
+  case ('1')  ! RK4 スキーム
 
-  !-- ѿι
+  !-- 変数の更新
      do j=1,ny
         do i=1,nx
            omega_tmp(i,j)=omega_new(i,j)
@@ -38,17 +38,17 @@ subroutine time_schematic( step )
         end do
      end do
 
-  !-- RK4 ΤȤΤѤѿν force_solv ȤΩ RK4 ΤȤΤư.
+  !-- RK4 のときのみ用いる全強制変数の初期化 force_solv とは独立で RK4 のときのみ動作する.
 
      call real_init( forcea_omega )
 
-     do ct=1,4  ! RK4 η򤽤줾׻
+     do ct=1,4  ! RK4 の傾きをそれぞれ計算
 
-     !-- ׻.
+     !-- 強制項を計算.
 
         call force()
 
-!--  ʬ (RK4 ˡ)
+!--  時間積分 (RK4 法)
 !$omp parallel default(shared)
 !$omp do schedule(dynamic) private(j,i)
         do j=1,ny
@@ -74,7 +74,7 @@ subroutine time_schematic( step )
 !$omp end do
 !$omp end parallel
 
-!-- ΰαپ줫ήؿջ
+!-- 内部領域の渦度場から流線関数場を逆算
 
         pois_force=0.0
 
@@ -112,23 +112,23 @@ subroutine time_schematic( step )
 
      end do
 
-!-- 
-!-- ήή -> ή® => psi : ή˿ľѲ, omega : 0
-!-- ήήи -> ˿ľήϤʤ => psi, omega : Υޥեå
-!-- ¦ -> ͳ٤ -> psi ήƱͤǰ, omega : 0
-!--  -> ٤ʤ -> psi : 0, omega : ¦ psi ư.
+!-- 境界条件の設定
+!-- 一般流の流入口 -> 流速一定 => psi : 流れに垂直な方向に線形変化, omega : 0
+!-- 一般流の流出口 -> 口に垂直な流れはない => psi, omega : ノイマンフラックスゼロ条件
+!-- 側壁 -> 自由すべり条件 -> psi は流入口と同じ値で一定, omega : 0
+!-- 内部境界 -> すべりなし -> psi : 0, omega : 内側の psi からの変動値.
 
      call set_omega_inner( x, y, psi_new, ibo, bndo )
      call bound_set( x, y, omega_new, ibo, bndo, undef )
 
-  case ('2')  ! Leap Frog 
+  case ('2')  ! Leap Frog スキーム
 
      if(step==1)then
         do j=1,ny
            do i=1,nx
               if(calc_flag(i,j).eqv..true.)then
-                 omega_tmp(i,j)=omega_new(i,j)  ! old ()  tmp (1 ƥå) .
-                 omega_old(i,j)=omega_new(i,j)  ! new (1 ƥå)  old () .
+                 omega_tmp(i,j)=omega_new(i,j)  ! old (今) を tmp (1 ステップ前) に.
+                 omega_old(i,j)=omega_new(i,j)  ! new (1 ステップ先) を old (今) に.
               end if
            end do
         end do
@@ -136,14 +136,14 @@ subroutine time_schematic( step )
         do j=1,ny
            do i=1,nx
               if(calc_flag(i,j).eqv..true.)then
-                 omega_tmp(i,j)=omega_old(i,j)  ! old ()  tmp (1 ƥå) .
-                 omega_old(i,j)=omega_new(i,j)  ! new (1 ƥå)  old () .
+                 omega_tmp(i,j)=omega_old(i,j)  ! old (今) を tmp (1 ステップ前) に.
+                 omega_old(i,j)=omega_new(i,j)  ! new (1 ステップ先) を old (今) に.
               end if
            end do
         end do
      end if
 
-  !-- ׻.
+  !-- 強制項を計算.
 
      call force()
 
@@ -177,7 +177,7 @@ subroutine time_schematic( step )
 
      end if
 
-!-- ΰαپ줫ήؿջ
+!-- 内部領域の渦度場から流線関数場を逆算
 
      do j=1,ny
         do i=1,nx
@@ -194,11 +194,11 @@ subroutine time_schematic( step )
   &                       bound_opt=bndp, undef=undef, inner_bound=ibp,  &
   &                       init_flag=.false. )
 
-!-- 
-!-- ήή -> ή® => psi : ή˿ľѲ, omega : 0
-!-- ήήи -> ˿ľήϤʤ => psi, omega : Υޥեå
-!-- ¦ -> ͳ٤ -> psi ήƱͤǰ, omega : 0
-!--  -> ٤ʤ -> psi : 0, omega : ¦ psi ư.
+!-- 境界条件の設定
+!-- 一般流の流入口 -> 流速一定 => psi : 流れに垂直な方向に線形変化, omega : 0
+!-- 一般流の流出口 -> 口に垂直な流れはない => psi, omega : ノイマンフラックスゼロ条件
+!-- 側壁 -> 自由すべり条件 -> psi は流入口と同じ値で一定, omega : 0
+!-- 内部境界 -> すべりなし -> psi : 0, omega : 内側の psi からの変動値.
 
      call set_omega_inner( x, y, psi_new, ibo, bndo )
      call bound_set( x, y, omega_new, ibo, bndo, undef )
