@@ -17,22 +17,23 @@ program make_init
 
   implicit none
 
-!-- do loop ѿ
+!-- do loop 用変数の定義
   integer :: i, j, k, nl
 
-!-- 
+!-- 作業用配列
   integer :: iz
   integer, dimension(4) :: iord
   real :: coer, coez, coev
   real, parameter :: r0=412.5e3
   real, dimension(:), allocatable :: ht, pr, tm, rho, qv
   real, dimension(:), allocatable :: tmpp, tmpt, tmpq, tmpr
-  real, dimension(:,:), allocatable :: rhoi, tmpc
+  real, dimension(:), allocatable :: tmppz, tmprz
+  real, dimension(:,:), allocatable :: rhoi, tmpc, p2_i, rho2i, v_ret, dv
   character(50), dimension(:,:), allocatable :: cval
 
   write(*,*) "starting program."
 
-!-- namelist ɤ߹
+!-- namelist の読み込み
 
   call read_name()
 
@@ -40,26 +41,32 @@ program make_init
 
   call val_allocate()
 
-!-- ǡκɸϤϤʤФʤʤ.
+!-- 初期データの座標系はこちらで定義しなければならない.
 
   r_i=(/((rimin+dri*(i-1)),i=1,nri)/)
   z_i=(/((zimin+dzi*(i-1)),i=1,nzi)/)
 
-!-- ¾ѿ
+!-- その他変数の配列割付
   allocate(tmpp(nzi))
   allocate(tmpt(nzi))
   allocate(tmpq(nzi))
   allocate(tmpr(nzi))
   allocate(rhoi(nri,nzi))
+  allocate(p2_i(nri,nzi))
+  allocate(rho2i(nri,nzi))
+  allocate(v_ret(nri,nzi))
+  allocate(dv(nri,nzi))
   allocate(tmpc(nri,nzi))
+  allocate(tmppz(nri))
+  allocate(tmprz(nri))
 
-!-- ˥ͤѿΤ, Ƥθ岿⤷ʤ.
+!-- 初期にゼロ値が入る変数のみ, 初期化してその後何もしない.
   u_i=0.0
   w_i=0.0
   ql_i=0.0
   tmpc=coril
 
-!-- ǥ󥰥ǡǮϳѿɤ߹.
+!-- サウンディングデータから各熱力学変数の読み込み.
 
   nl=line_number_counter( trim(sname) )-2
   allocate(cval(4,nl))
@@ -107,13 +114,13 @@ program make_init
   end do
 
 !write(*,*) "zi check", z_i
-!-- ǥ󥰥ǡǡ줿ľ٤ޤ.
+!-- サウンデイングデータを初期データで定義された鉛直高度に内挿する.
   call auto_interpolation_1d( ht, z_i, pr, tmpp, undef=undef, undefr=undef )
   call auto_interpolation_1d( ht, z_i, tm, tmpt, undef=undef, undefr=undef )
   call auto_interpolation_1d( ht, z_i, qv, tmpq, undef=undef, undefr=undef )
   call auto_interpolation_1d( ht, z_i, rho, tmpr, undef=undef, undefr=undef )
 
-!-- ̥ǡʤΤ,  2 ʬ鳰ޤԤ.
+!-- 海面データがないので, 下層 2 層分から外挿を行う.
   call interpo_search_1d( z_i, ht(1), iz, undeff=0 )
 
   if((iz>0).and.(z_i(1)<ht(1)))then
@@ -129,7 +136,7 @@ program make_init
      end do
   end if
 
-!-- ®η׻.
+!-- 接線風速の計算.
 
   do k=1,nzi
      do j=1,nri
@@ -154,8 +161,29 @@ program make_init
      end do
   end do
 
-!-- ϳإХ󥹤褦Ĵ.
-  call hydro_grad_eqb( r_i, z_i, tmpc, v_i, tmpp, tmpr, p_i, rhoi, dl=2 )
+!-- 静力学バランスするように調節.
+  call hydro_grad_eqb_it( r_i, z_i, tmpc, v_i, tmpp, tmpr, p_i, rhoi, dl=2 )
+  v_ret=v_i
+  do k=1,nzi  ! もとの風速分布と比較
+     do j=2,nri-1
+        if(p_i(j+1,k)>=p_i(j-1,k))then
+           v_ret(j,k)=0.5*(-tmpc(j,1)*r_i(j)  &
+  &                     +sqrt((tmpc(j,1)*r_i(j))**2+4.0*r_i(j)*(p_i(j+1,k)-p_i(j-1,k))/((r_i(j+1)-r_i(j-1))*rhoi(j,k))))
+        else
+           if(tmpc(j,1)*r_i(j)<v_i(j,k))then  ! 旋衡風的 (遠心力大きい)
+              v_ret(j,k)=0.5*(tmpc(j,1)*r_i(j)  &
+  &                       +sqrt((tmpc(j,1)*r_i(j))**2+4.0*r_i(j)*abs(p_i(j+1,k)-p_i(j-1,k))/((r_i(j+1)-r_i(j-1))*rhoi(j,k))))
+           else  ! 地衡風的 (コリオリ力大きい)
+              v_ret(j,k)=0.5*(tmpc(j,1)*r_i(j)  &
+  &                       -sqrt((tmpc(j,1)*r_i(j))**2+4.0*r_i(j)*abs(p_i(j+1,k)-p_i(j-1,k))/((r_i(j+1)-r_i(j-1))*rhoi(j,k))))
+           end if
+        end if
+     end do
+  end do
+  dv=v_i-v_ret
+  !!tmppz=tmpp(nzi)
+  !!tmprz=tmpr(nzi)
+  !!call hydro_grad_eqb( r_i, z_i, tmpc, v_i, tmpp, tmpr, tmppz, tmprz, p2_i, rho2i, dl=2 )
 
   do k=1,nzi
      do j=1,nri
@@ -168,7 +196,7 @@ program make_init
      end do
   end do
 
-!-- ϥեν
+!-- 出力ファイルの初期化
   call HistoryCreate( file=trim(finame), title='RE87 result data', &
   & source='test', institution='test', dims=(/'r', 'z'/),  &
   & dimsizes=(/nri, nzi/),  & 
@@ -190,6 +218,9 @@ program make_init
   call HistoryAddVariable( varname='p', dims=(/'r','z'/), &
     & longname='Pressure', units='1', xtype='float')
 
+  call HistoryAddVariable( varname='rho', dims=(/'r','z'/), &
+    & longname='Density', units='1', xtype='float')
+
   call HistoryAddVariable( varname='t', dims=(/'r','z'/), &
     & longname='Potential Temperature', units='K', xtype='float')
 
@@ -199,17 +230,26 @@ program make_init
   call HistoryAddVariable( varname='ql', dims=(/'r','z'/), &
     & longname='Condensation Mixing Ratio', units='kg kg-1', xtype='float')
 
-!-- ͥեؤ
+  call HistoryAddVariable( varname='vret', dims=(/'r','z'/), &
+    & longname='Retrieved T wind', units='1', xtype='float')
+
+  call HistoryAddVariable( varname='dv', dims=(/'r','z'/), &
+    & longname='Difference between v and vret', units='1', xtype='float')
+
+!-- 初期値ファイルへの入力
 
   call HistoryPut( 'u', u_i(1:nri,1:nzi) )
   call HistoryPut( 'v', v_i(1:nri,1:nzi) )
   call HistoryPut( 'w', w_i(1:nri,1:nzi) )
   call HistoryPut( 'p', p_i(1:nri,1:nzi) )
+  call HistoryPut( 'rho', rhoi(1:nri,1:nzi) )
   call HistoryPut( 't', t_i(1:nri,1:nzi) )
   call HistoryPut( 'qv', qv_i(1:nri,1:nzi) )
   call HistoryPut( 'ql', ql_i(1:nri,1:nzi) )
+  call HistoryPut( 'vret', v_ret(1:nri,1:nzi) )
+  call HistoryPut( 'dv', dv(1:nri,1:nzi) )
 
-!-- ȥå
+!-- ストップ
 
   write(*,*) "program normally stops."
 
