@@ -1,6 +1,6 @@
 module sub_calc
 
-! ֽ롼
+! サブ処理ルーチン
   use Thermo_Function
 
 contains
@@ -8,7 +8,7 @@ contains
 subroutine dmp_val( r_u, r_s, z_w, z_s,  &
   &                 u_i, v_i, w_i, p_i, pb_s, t_i, qv_i, qc_i, ql_i,  &
   &                 u_dmp, v_dmp, w_dmp, p_dmp, t_dmp, qv_dmp, qc_dmp, ql_dmp )
-!-- ͽѿ򥹥顼˺.
+!-- 予報変数をスカラー点に再配置.
   use Thermo_Const
   implicit none
   real, intent(in) :: r_u(:)
@@ -71,7 +71,7 @@ end subroutine dmp_val
 
 subroutine dmp_suf( z_s, u_i, v_i, w_i, p_i, t_i, qv_i, qc_i, ql_i, Tsurf,  &
   &                 u_dmp, v_dmp, w_dmp, p_dmp, t_dmp, qv_dmp, qc_dmp, ql_dmp )
-!-- ͽѿ򥹥顼˺.
+!-- 予報変数をスカラー点に再配置.
   use Thermo_Const
   implicit none
   real, intent(in) :: z_s
@@ -129,24 +129,24 @@ end subroutine dmp_suf
 
 
 subroutine bound_set( u_in, u_out, w_bot, w_top )
-! ꤹ. Ǥ, u_out ɤ߹. ⤷ʤ.
+! 境界条件を設定する. ここでは, u_out は読み込むだけ. 何もしない.
   implicit none
-  real, intent(inout) :: u_in(:)            ! r ¦ʿ® [m/s]
-  real, intent(inout) :: u_out(size(u_in))  ! r ¦ʿ® [m/s]
-  real, intent(inout) :: w_bot(:)            ! z üľ® [m/s]
-  real, intent(inout) :: w_top(size(w_bot))  ! z üľ® [m/s]
+  real, intent(inout) :: u_in(:)            ! r 方向内側水平風速 [m/s]
+  real, intent(inout) :: u_out(size(u_in))  ! r 方向外側水平風速 [m/s]
+  real, intent(inout) :: w_bot(:)            ! z 方向下端鉛直風速 [m/s]
+  real, intent(inout) :: w_top(size(w_bot))  ! z 方向上端鉛直風速 [m/s]
 
   integer :: i, j, nw, nu
 
   nu=size(u_in)
   nw=size(w_bot)
 
-  do i=1,nw  ! , rigid lid Τ
+  do i=1,nw  ! 現在, rigid lid のみ
      w_bot(i)=0.0
      w_top(i)=0.0
   end do
 
-  do i=1,nu  ! , ¦ rigid lid Τ
+  do i=1,nu  ! 現在, 内側 rigid lid のみ
      u_in(i)=0.0
   end do
 
@@ -154,18 +154,18 @@ end subroutine bound_set
 
 
 subroutine grad_back_1d( x, u, val )
-! 1 Υ顼ѿθۤ򥹥åɳʻҤǷ׻.
-!  xv(i) ˤѿ u θۤȤ,
-! u  xu ȤɸƤ, ᤿ۤϤȾʻҤ줿 xv Ȥ
-! ǵ᤿Ȥ.
-! ΤȤ, xv(i) Ǥθۤ,
-! (u(i)-u(i-1))/(xu(i)-xu(i-1)) Ƿ׻.
+! 1 次元のスカラー変数の勾配をスタッガード格子で計算する.
+! ある点 xv(i) における変数 u の勾配を求めるとき,
+! u は xu という座標で定義されており, 求めたい勾配はその半格子ずれた xv という
+! 点で求めたいとする.
+! このとき, xv(i) での勾配は,
+! (u(i)-u(i-1))/(xu(i)-xu(i-1)) で計算される.
   implicit none
-  real, intent(in) :: x(:)  ! u ɸ
-  real, intent(in) :: u(size(x))  ! ζб 1 顼
-  real, intent(inout) :: val(size(x))  ! 顼ͤ x θ
-  integer :: i  ! 졼ź
-  integer :: nx  ! ǿ
+  real, intent(in) :: x(:)  ! u の定義点座標
+  real, intent(in) :: u(size(x))  ! 上の空間配列に対応する 1 次元スカラー値
+  real, intent(inout) :: val(size(x))  ! スカラー値の x 方向の勾配
+  integer :: i  ! イタレーション用添字
+  integer :: nx  ! 配列要素数
   real :: scalex(size(x))
 
   nx=size(x)
@@ -174,25 +174,25 @@ subroutine grad_back_1d( x, u, val )
      val(i)=(u(i)-u(i-1))/(x(i)-x(i-1))
   end do
 
-!-- ǡΤʤξüν ---
+!-- データ数のない両端の処理 ---
   val(1)=0.0
 
 end subroutine grad_back_1d
 
 
 subroutine grad_for_1d( x, u, val )
-! 1 Υ顼ѿθۤ򥹥åɳʻҤǷ׻.
-!  xv(i) ˤѿ u θۤȤ,
-! u  xu ȤɸƤ, ᤿ۤϤȾʻҤ줿 xv Ȥ
-! ǵ᤿Ȥ.
-! ΤȤ, xv(i) Ǥθۤ,
-! (u(i+1)-u(i))/(xu(i+1)-xu(i)) Ƿ׻.
+! 1 次元のスカラー変数の勾配をスタッガード格子で計算する.
+! ある点 xv(i) における変数 u の勾配を求めるとき,
+! u は xu という座標で定義されており, 求めたい勾配はその半格子ずれた xv という
+! 点で求めたいとする.
+! このとき, xv(i) での勾配は,
+! (u(i+1)-u(i))/(xu(i+1)-xu(i)) で計算される.
   implicit none
-  real, intent(in) :: x(:)  ! u ɸ
-  real, intent(in) :: u(size(x))  ! ζб 1 顼
-  real, intent(inout) :: val(size(x))  ! 顼ͤ x θ
-  integer :: i  ! 졼ź
-  integer :: nx  ! ǿ
+  real, intent(in) :: x(:)  ! u の定義点座標
+  real, intent(in) :: u(size(x))  ! 上の空間配列に対応する 1 次元スカラー値
+  real, intent(inout) :: val(size(x))  ! スカラー値の x 方向の勾配
+  integer :: i  ! イタレーション用添字
+  integer :: nx  ! 配列要素数
   real :: scalex(size(x))
 
   nx=size(x)
@@ -201,26 +201,26 @@ subroutine grad_for_1d( x, u, val )
      val(i)=(u(i+1)-u(i))/(x(i+1)-x(i))
   end do
 
-!-- ǡΤʤξüν ---
+!-- データ数のない両端の処理 ---
   val(nx)=0.0
 
 end subroutine grad_for_1d
 
 
 real function hydro_calc( z1, t1, p1, z2, t2, p2, z0 )
-! ϳʿդꤷȤ, ɽ̤ΰ [Pa]  2 ؤ
-! ޷׻.
-! ¤, z0 Ĵ᤹Ǥդι٤Ǥͤ׻ǽ.
-! ׻ˤ, (p_2+p_0-2p_1)/2dz=-grho_1 ջ.
+! 静力学平衡を仮定したときに, 地表面の圧力 [Pa] を上 2 層から
+! 外挿計算する.
+! 実は, z0 を調節すれば任意の高度での値を計算可能.
+! 計算方針は, (p_2+p_0-2p_1)/2dz=-grho_1 から逆算する.
   use Phys_Const
   implicit none
-  real, intent(in) :: z1   !  1 إ顼ιٺɸ
-  real, intent(in) :: p1   !  1 إ顼ΰ [Pa]
-  real, intent(in) :: t1   !  1 إ顼β [K]
-  real, intent(in) :: z2   !  2 إ顼ιٺɸ
-  real, intent(in) :: p2   !  2 إ顼ΰ [Pa]
-  real, intent(in) :: t2   !  2 إ顼β [K]
-  real, intent(in) :: z0   ! ɽ̤ιٺɸ
+  real, intent(in) :: z1   ! 第 1 層スカラー点の高度座標
+  real, intent(in) :: p1   ! 第 1 層スカラー点の圧力 [Pa]
+  real, intent(in) :: t1   ! 第 1 層スカラー点の温度 [K]
+  real, intent(in) :: z2   ! 第 2 層スカラー点の高度座標
+  real, intent(in) :: p2   ! 第 2 層スカラー点の圧度 [Pa]
+  real, intent(in) :: t2   ! 第 2 層スカラー点の温位 [K]
+  real, intent(in) :: z0   ! 地表面の高度座標
   real :: rho
 
   rho=TP_2_rho( t1, p1 )
@@ -252,18 +252,18 @@ end subroutine val_check
 
 
 real function ext_1d( x1, x2, v1, v2, point )
-! x1, x2  2 Ǥ v1, v2 ͤѤ, point Ǥͤޤ.
-! x1, x2 а֤ưȽꤹΤ, point  x1, x2 Τɤ¦
-! 뤫ϵˤʤƤ褤.
-! , x1 < x2 ǤʤФʤʤ.
+! x1, x2 の 2 点での値 v1, v2 の値を用いて, point 点での値を線形外挿する.
+! x1, x2 からの相対位置を自動判定するので, point が x1, x2 のどちら側に
+! あるかは気にしなくてよい.
+! ただし, x1 < x2 でなければならない.
 
   implicit none
 
-  real, intent(in) :: x1  !  1 
-  real, intent(in) :: x2  !  2 
-  real, intent(in) :: v1  !  1 Ǥ
-  real, intent(in) :: v2  !  2 Ǥ
-  real, intent(in) :: point  ! 
+  real, intent(in) :: x1  ! 第 1 点
+  real, intent(in) :: x2  ! 第 2 点
+  real, intent(in) :: v1  ! 第 1 点での値
+  real, intent(in) :: v2  ! 第 2 点での値
+  real, intent(in) :: point  ! 外挿点
   real :: df, dx
 
   if(x1>=x2)then
