@@ -2,7 +2,7 @@
 ! Copyright (C) 2009-2015 GFD Dennou Club. All rights reserved.
 !---------------------------------------------------------------
 
-module max_min  ! ׻⥸塼 1
+module max_min  ! 代数計算モジュール 1
 
 interface max_val_1d
 
@@ -44,14 +44,14 @@ contains
 
 
 subroutine max_val_1di(var, mamn, mamv, undef)
-  ! 1 Ѻ, ֹ롼
+  ! 1 次元配列用最大値, 該当配列要素番号取得ルーチン
   implicit none
-  integer, intent(in) :: var(:)  ! õ
-  integer, intent(inout) :: mamn  ! κͤ˳ֹ
-  integer, intent(inout) :: mamv  ! κ
-  integer, intent(in), optional :: undef  ! ̤
-  integer :: nx  ! Ŀ(size ؿǼư׻)
-  integer :: i  ! 졼ź
+  integer, intent(in) :: var(:)  ! 最大値探索配列
+  integer, intent(inout) :: mamn  ! 配列内の最大値に該当する要素番号
+  integer, intent(inout) :: mamv  ! 配列内の最大値
+  integer, intent(in), optional :: undef  ! 未定義
+  integer :: nx  ! 配列個数(size 関数で自動計算)
+  integer :: i  ! イタレーション用添字
   logical :: undeflag
 
   nx=size(var)
@@ -98,14 +98,14 @@ end subroutine max_val_1di
 !-----------------------------
 
 subroutine max_val_1df(var, mamn, mamv, undef)
-  ! 1 Ѻ, ֹ롼
+  ! 1 次元配列用最大値, 該当配列要素番号取得ルーチン
   implicit none
-  real, intent(in) :: var(:)  ! õ
-  integer, intent(inout) :: mamn  ! κͤ˳ֹ
-  real, intent(inout) :: mamv  ! κ
-  real, intent(in), optional :: undef  ! ̤
-  integer :: nx  ! Ŀ(size ؿǼư׻)
-  integer :: i  ! 졼ź
+  real, intent(in) :: var(:)  ! 最大値探索配列
+  integer, intent(inout) :: mamn  ! 配列内の最大値に該当する要素番号
+  real, intent(inout) :: mamv  ! 配列内の最大値
+  real, intent(in), optional :: undef  ! 未定義
+  integer :: nx  ! 配列個数(size 関数で自動計算)
+  integer :: i  ! イタレーション用添字
   logical :: undeflag
 
   nx=size(var)
@@ -152,14 +152,14 @@ end subroutine max_val_1df
 !-----------------------------
 
 subroutine max_val_1dd(var, mamn, mamv, undef)
-  ! 1 Ѻ, ֹ롼
+  ! 1 次元配列用最大値, 該当配列要素番号取得ルーチン
   implicit none
-  double precision, intent(in) :: var(:)  ! õ
-  integer, intent(inout) :: mamn  ! κͤ˳ֹ
-  double precision, intent(inout) :: mamv  ! κ
-  double precision, intent(in), optional :: undef  ! ̤
-  integer :: nx  ! Ŀ(size ؿǼư׻)
-  integer :: i  ! 졼ź
+  double precision, intent(in) :: var(:)  ! 最大値探索配列
+  integer, intent(inout) :: mamn  ! 配列内の最大値に該当する要素番号
+  double precision, intent(inout) :: mamv  ! 配列内の最大値
+  double precision, intent(in), optional :: undef  ! 未定義
+  integer :: nx  ! 配列個数(size 関数で自動計算)
+  integer :: i  ! イタレーション用添字
   logical :: undeflag
 
   nx=size(var)
@@ -206,20 +206,20 @@ end subroutine max_val_1dd
 !-----------------------------
 
 subroutine max_val_2di(var, mamnx, mamny, mamv, undef)
-! 2 Ѻ, ֹ롼
-!-- 2 Ǥ, x  y  1 롼Ƥ, Ǥκͤ1
-!-- Ǽ, Ф1롼Ѥ뤳Ȥ, ΤκͤФ
+! 2 次元配列用最大値, 該当配列要素番号取得ルーチン
+!-- 2 次元版は, x 方向に y 回 1 次元ルーチンを呼び, 各要素の最大値を1次元配列に
+!-- 格納後, その配列に対して1次元ルーチンを作用させることで, 全体の最大値を出す
   implicit none
-  integer, intent(in) :: var(:,:)  ! 2 õ
-  integer, intent(inout) :: mamnx  ! κͤ˳ 1 ֹ
-  integer, intent(inout) :: mamny  ! κͤ˳ 2 ֹ
-  integer, intent(inout) :: mamv  ! κ
-  integer, intent(in), optional :: undef  ! ̤
-  integer :: nx  !  1 ǤĿ(size ؿǼư׻)
-  integer :: ny  !  2 ǤĿ(size ؿǼư׻)
-  integer :: j  ! 졼ź
-  integer :: tmp(size(var,2))  ! 
-  integer :: tmp_num(size(var,2))  ! 
+  integer, intent(in) :: var(:,:)  ! 2 次元最大値探索配列
+  integer, intent(inout) :: mamnx  ! 配列内の最大値に該当する第 1 配列要素番号
+  integer, intent(inout) :: mamny  ! 配列内の最大値に該当する第 2 配列要素番号
+  integer, intent(inout) :: mamv  ! 配列内の最大値
+  integer, intent(in), optional :: undef  ! 未定義
+  integer :: nx  ! 第 1 要素の配列個数(size 関数で自動計算)
+  integer :: ny  ! 第 2 要素の配列個数(size 関数で自動計算)
+  integer :: j  ! イタレーション用添字
+  integer :: tmp(size(var,2))  ! 作業用配列
+  integer :: tmp_num(size(var,2))  ! 作業用配列
 
   nx=size(var,1)
   ny=size(var,2)
@@ -253,20 +253,20 @@ end subroutine max_val_2di
 !-----------------------------
 
 subroutine max_val_2df(var, mamnx, mamny, mamv, undef)
-! 2 Ѻ, ֹ롼
-!-- 2 Ǥ, x  y  1 롼Ƥ, Ǥκͤ1
-!-- Ǽ, Ф1롼Ѥ뤳Ȥ, ΤκͤФ
+! 2 次元配列用最大値, 該当配列要素番号取得ルーチン
+!-- 2 次元版は, x 方向に y 回 1 次元ルーチンを呼び, 各要素の最大値を1次元配列に
+!-- 格納後, その配列に対して1次元ルーチンを作用させることで, 全体の最大値を出す
   implicit none
-  real, intent(in) :: var(:,:)  ! 2 õ
-  integer, intent(inout) :: mamnx  ! κͤ˳ 1 ֹ
-  integer, intent(inout) :: mamny  ! κͤ˳ 2 ֹ
-  real, intent(inout) :: mamv  ! κ
-  real, intent(in), optional :: undef  ! ̤
-  integer :: nx  !  1 ǤĿ(size ؿǼư׻)
-  integer :: ny  !  2 ǤĿ(size ؿǼư׻)
-  integer :: j  ! 졼ź
-  real :: tmp(size(var,2))  ! 
-  integer :: tmp_num(size(var,2))  ! 
+  real, intent(in) :: var(:,:)  ! 2 次元最大値探索配列
+  integer, intent(inout) :: mamnx  ! 配列内の最大値に該当する第 1 配列要素番号
+  integer, intent(inout) :: mamny  ! 配列内の最大値に該当する第 2 配列要素番号
+  real, intent(inout) :: mamv  ! 配列内の最大値
+  real, intent(in), optional :: undef  ! 未定義
+  integer :: nx  ! 第 1 要素の配列個数(size 関数で自動計算)
+  integer :: ny  ! 第 2 要素の配列個数(size 関数で自動計算)
+  integer :: j  ! イタレーション用添字
+  real :: tmp(size(var,2))  ! 作業用配列
+  integer :: tmp_num(size(var,2))  ! 作業用配列
 
   nx=size(var,1)
   ny=size(var,2)
@@ -300,20 +300,20 @@ end subroutine max_val_2df
 !-----------------------------
 
 subroutine max_val_2dd(var, mamnx, mamny, mamv, undef)
-! 2 Ѻ, ֹ롼
-!-- 2 Ǥ, x  y  1 롼Ƥ, Ǥκͤ1
-!-- Ǽ, Ф1롼Ѥ뤳Ȥ, ΤκͤФ
+! 2 次元配列用最大値, 該当配列要素番号取得ルーチン
+!-- 2 次元版は, x 方向に y 回 1 次元ルーチンを呼び, 各要素の最大値を1次元配列に
+!-- 格納後, その配列に対して1次元ルーチンを作用させることで, 全体の最大値を出す
   implicit none
-  double precision, intent(in) :: var(:,:)  ! 2 õ
-  integer, intent(inout) :: mamnx  ! κͤ˳ 1 ֹ
-  integer, intent(inout) :: mamny  ! κͤ˳ 2 ֹ
-  double precision, intent(inout) :: mamv  ! κ
-  double precision, intent(in), optional :: undef  ! ̤
-  integer :: nx  !  1 ǤĿ(size ؿǼư׻)
-  integer :: ny  !  2 ǤĿ(size ؿǼư׻)
-  integer :: j  ! 졼ź
-  double precision :: tmp(size(var,2))  ! 
-  integer :: tmp_num(size(var,2))  ! 
+  double precision, intent(in) :: var(:,:)  ! 2 次元最大値探索配列
+  integer, intent(inout) :: mamnx  ! 配列内の最大値に該当する第 1 配列要素番号
+  integer, intent(inout) :: mamny  ! 配列内の最大値に該当する第 2 配列要素番号
+  double precision, intent(inout) :: mamv  ! 配列内の最大値
+  double precision, intent(in), optional :: undef  ! 未定義
+  integer :: nx  ! 第 1 要素の配列個数(size 関数で自動計算)
+  integer :: ny  ! 第 2 要素の配列個数(size 関数で自動計算)
+  integer :: j  ! イタレーション用添字
+  double precision :: tmp(size(var,2))  ! 作業用配列
+  integer :: tmp_num(size(var,2))  ! 作業用配列
 
   nx=size(var,1)
   ny=size(var,2)
@@ -347,21 +347,21 @@ end subroutine max_val_2dd
 !-----------------------------
 
 subroutine max_val_3di(var, mamnx, mamny, mamnz, mamv, undef)
-  ! 3 Ѻ, ֹ롼
+  ! 3 次元配列用最大値, 該当配列要素番号取得ルーチン
   implicit none
-  integer, intent(in) :: var(:,:,:)  ! 3 õ
-  integer, intent(inout) :: mamnx  ! κͤ˳ 1 ֹ
-  integer, intent(inout) :: mamny  ! κͤ˳ 2 ֹ
-  integer, intent(inout) :: mamnz  ! κͤ˳ 3 ֹ
-  integer, intent(inout) :: mamv  ! κ
-  integer, intent(in), optional :: undef  ! ̤
-  integer :: nx  !  1 ǤĿ(size ؿǼư׻)
-  integer :: ny  !  2 ǤĿ(size ؿǼư׻)
-  integer :: nz  !  3 ǤĿ(size ؿǼư׻)
-  integer :: j  ! 졼ź
-  integer :: tmp(size(var,3))  ! 
-  integer :: tmp_num1(size(var,3))  ! 
-  integer :: tmp_num2(size(var,3))  ! 
+  integer, intent(in) :: var(:,:,:)  ! 3 次元最大値探索配列
+  integer, intent(inout) :: mamnx  ! 配列内の最大値に該当する第 1 配列要素番号
+  integer, intent(inout) :: mamny  ! 配列内の最大値に該当する第 2 配列要素番号
+  integer, intent(inout) :: mamnz  ! 配列内の最大値に該当する第 3 配列要素番号
+  integer, intent(inout) :: mamv  ! 配列内の最大値
+  integer, intent(in), optional :: undef  ! 未定義
+  integer :: nx  ! 第 1 要素の配列個数(size 関数で自動計算)
+  integer :: ny  ! 第 2 要素の配列個数(size 関数で自動計算)
+  integer :: nz  ! 第 3 要素の配列個数(size 関数で自動計算)
+  integer :: j  ! イタレーション用添字
+  integer :: tmp(size(var,3))  ! 作業用配列
+  integer :: tmp_num1(size(var,3))  ! 作業用配列
+  integer :: tmp_num2(size(var,3))  ! 作業用配列
 
   nx=size(var,1)
   ny=size(var,2)
@@ -399,21 +399,21 @@ end subroutine max_val_3di
 !-----------------------------
 
 subroutine max_val_3df(var, mamnx, mamny, mamnz, mamv, undef)
-  ! 3 Ѻ, ֹ롼
+  ! 3 次元配列用最大値, 該当配列要素番号取得ルーチン
   implicit none
-  real, intent(in) :: var(:,:,:)  ! 3 õ
-  integer, intent(inout) :: mamnx  ! κͤ˳ 1 ֹ
-  integer, intent(inout) :: mamny  ! κͤ˳ 2 ֹ
-  integer, intent(inout) :: mamnz  ! κͤ˳ 3 ֹ
-  real, intent(inout) :: mamv  ! κ
-  real, intent(in), optional :: undef  ! ̤
-  integer :: nx  !  1 ǤĿ(size ؿǼư׻)
-  integer :: ny  !  2 ǤĿ(size ؿǼư׻)
-  integer :: nz  !  3 ǤĿ(size ؿǼư׻)
-  integer :: j  ! 졼ź
-  real :: tmp(size(var,3))  ! 
-  integer :: tmp_num1(size(var,3))  ! 
-  integer :: tmp_num2(size(var,3))  ! 
+  real, intent(in) :: var(:,:,:)  ! 3 次元最大値探索配列
+  integer, intent(inout) :: mamnx  ! 配列内の最大値に該当する第 1 配列要素番号
+  integer, intent(inout) :: mamny  ! 配列内の最大値に該当する第 2 配列要素番号
+  integer, intent(inout) :: mamnz  ! 配列内の最大値に該当する第 3 配列要素番号
+  real, intent(inout) :: mamv  ! 配列内の最大値
+  real, intent(in), optional :: undef  ! 未定義
+  integer :: nx  ! 第 1 要素の配列個数(size 関数で自動計算)
+  integer :: ny  ! 第 2 要素の配列個数(size 関数で自動計算)
+  integer :: nz  ! 第 3 要素の配列個数(size 関数で自動計算)
+  integer :: j  ! イタレーション用添字
+  real :: tmp(size(var,3))  ! 作業用配列
+  integer :: tmp_num1(size(var,3))  ! 作業用配列
+  integer :: tmp_num2(size(var,3))  ! 作業用配列
 
   nx=size(var,1)
   ny=size(var,2)
@@ -451,21 +451,21 @@ end subroutine max_val_3df
 !-----------------------------
 
 subroutine max_val_3dd(var, mamnx, mamny, mamnz, mamv, undef)
-  ! 3 Ѻ, ֹ롼
+  ! 3 次元配列用最大値, 該当配列要素番号取得ルーチン
   implicit none
-  double precision, intent(in) :: var(:,:,:)  ! 3 õ
-  integer, intent(inout) :: mamnx  ! κͤ˳ 1 ֹ
-  integer, intent(inout) :: mamny  ! κͤ˳ 2 ֹ
-  integer, intent(inout) :: mamnz  ! κͤ˳ 3 ֹ
-  double precision, intent(inout) :: mamv  ! κ
-  double precision, intent(in), optional :: undef  ! ̤
-  integer :: nx  !  1 ǤĿ(size ؿǼư׻)
-  integer :: ny  !  2 ǤĿ(size ؿǼư׻)
-  integer :: nz  !  3 ǤĿ(size ؿǼư׻)
-  integer :: j  ! 졼ź
-  double precision :: tmp(size(var,3))  ! 
-  integer :: tmp_num1(size(var,3))  ! 
-  integer :: tmp_num2(size(var,3))  ! 
+  double precision, intent(in) :: var(:,:,:)  ! 3 次元最大値探索配列
+  integer, intent(inout) :: mamnx  ! 配列内の最大値に該当する第 1 配列要素番号
+  integer, intent(inout) :: mamny  ! 配列内の最大値に該当する第 2 配列要素番号
+  integer, intent(inout) :: mamnz  ! 配列内の最大値に該当する第 3 配列要素番号
+  double precision, intent(inout) :: mamv  ! 配列内の最大値
+  double precision, intent(in), optional :: undef  ! 未定義
+  integer :: nx  ! 第 1 要素の配列個数(size 関数で自動計算)
+  integer :: ny  ! 第 2 要素の配列個数(size 関数で自動計算)
+  integer :: nz  ! 第 3 要素の配列個数(size 関数で自動計算)
+  integer :: j  ! イタレーション用添字
+  double precision :: tmp(size(var,3))  ! 作業用配列
+  integer :: tmp_num1(size(var,3))  ! 作業用配列
+  integer :: tmp_num2(size(var,3))  ! 作業用配列
 
   nx=size(var,1)
   ny=size(var,2)
@@ -503,14 +503,14 @@ end subroutine max_val_3dd
 !-----------------------------
 
 subroutine min_val_1di(var, mimn, mimv, undef)
-!-- 1 ѺǾ, ֹ롼
+!-- 1 次元配列用最小値, 該当配列要素番号取得ルーチン
   implicit none
-  integer, intent(in) :: var(:)  ! Ǿõ
-  integer, intent(inout) :: mimn  ! κǾͤ˳ֹ
-  integer, intent(inout) :: mimv  ! κǾ
-  integer, intent(in), optional :: undef  ! ̤
-  integer :: nx  ! Ŀ(size ؿǼư׻)
-  integer :: i  ! 졼ź
+  integer, intent(in) :: var(:)  ! 最小値探索配列
+  integer, intent(inout) :: mimn  ! 配列内の最小値に該当する要素番号
+  integer, intent(inout) :: mimv  ! 配列内の最小値
+  integer, intent(in), optional :: undef  ! 未定義値
+  integer :: nx  ! 配列個数(size 関数で自動計算)
+  integer :: i  ! イタレーション用添字
   logical :: undeflag
 
   nx=size(var)
@@ -558,14 +558,14 @@ end subroutine min_val_1di
 !-----------------------------
 
 subroutine min_val_1df(var, mimn, mimv, undef)
-!-- 1 ѺǾ, ֹ롼
+!-- 1 次元配列用最小値, 該当配列要素番号取得ルーチン
   implicit none
-  real, intent(in) :: var(:)  ! Ǿõ
-  integer, intent(inout) :: mimn  ! κǾͤ˳ֹ
-  real, intent(inout) :: mimv  ! κǾ
-  real, intent(in), optional :: undef  ! ̤
-  integer :: nx  ! Ŀ(size ؿǼư׻)
-  integer :: i  ! 졼ź
+  real, intent(in) :: var(:)  ! 最小値探索配列
+  integer, intent(inout) :: mimn  ! 配列内の最小値に該当する要素番号
+  real, intent(inout) :: mimv  ! 配列内の最小値
+  real, intent(in), optional :: undef  ! 未定義値
+  integer :: nx  ! 配列個数(size 関数で自動計算)
+  integer :: i  ! イタレーション用添字
   logical :: undeflag
 
   nx=size(var)
@@ -613,14 +613,14 @@ end subroutine min_val_1df
 !-----------------------------
 
 subroutine min_val_1dd(var, mimn, mimv, undef)
-!-- 1 ѺǾ, ֹ롼
+!-- 1 次元配列用最小値, 該当配列要素番号取得ルーチン
   implicit none
-  double precision, intent(in) :: var(:)  ! Ǿõ
-  integer, intent(inout) :: mimn  ! κǾͤ˳ֹ
-  double precision, intent(inout) :: mimv  ! κǾ
-  double precision, intent(in), optional :: undef  ! ̤
-  integer :: nx  ! Ŀ(size ؿǼư׻)
-  integer :: i  ! 졼ź
+  double precision, intent(in) :: var(:)  ! 最小値探索配列
+  integer, intent(inout) :: mimn  ! 配列内の最小値に該当する要素番号
+  double precision, intent(inout) :: mimv  ! 配列内の最小値
+  double precision, intent(in), optional :: undef  ! 未定義値
+  integer :: nx  ! 配列個数(size 関数で自動計算)
+  integer :: i  ! イタレーション用添字
   logical :: undeflag
 
   nx=size(var)
@@ -668,20 +668,20 @@ end subroutine min_val_1dd
 !-----------------------------
 
 subroutine min_val_2di(var, mimnx, mimny, mimv, undef)
-! 2 ѺǾ, ֹ롼
-!-- 2 Ǥ, x  y  1 롼Ƥ, Ǥκͤ1
-!-- Ǽ, Ф1롼Ѥ뤳Ȥ, ΤκͤФ
+! 2 次元配列用最小値, 該当配列要素番号取得ルーチン
+!-- 2 次元版は, x 方向に y 回 1 次元ルーチンを呼び, 各要素の最大値を1次元配列に
+!-- 格納後, その配列に対して1次元ルーチンを作用させることで, 全体の最大値を出す
   implicit none
-  integer, intent(in) :: var(:,:)  ! 2 Ǿõ
-  integer, intent(inout) :: mimnx  ! κǾͤ˳ 1 ֹ
-  integer, intent(inout) :: mimny  ! κǾͤ˳ 2 ֹ
-  integer, intent(inout) :: mimv  ! κǾ
-  integer, intent(in), optional :: undef  ! ̤
-  integer :: nx  !  1 ǤĿ(size ؿǼư׻)
-  integer :: ny  !  2 ǤĿ(size ؿǼư׻)
-  integer :: j  ! 졼ź
-  integer :: tmp(size(var,2))  ! 
-  integer :: tmp_num(size(var,2))  ! 
+  integer, intent(in) :: var(:,:)  ! 2 次元最小値探索配列
+  integer, intent(inout) :: mimnx  ! 配列内の最小値に該当する第 1 配列要素番号
+  integer, intent(inout) :: mimny  ! 配列内の最小値に該当する第 2 配列要素番号
+  integer, intent(inout) :: mimv  ! 配列内の最小値
+  integer, intent(in), optional :: undef  ! 未定義値
+  integer :: nx  ! 第 1 要素の配列個数(size 関数で自動計算)
+  integer :: ny  ! 第 2 要素の配列個数(size 関数で自動計算)
+  integer :: j  ! イタレーション用添字
+  integer :: tmp(size(var,2))  ! 作業用配列
+  integer :: tmp_num(size(var,2))  ! 作業用配列
 
   nx=size(var,1)
   ny=size(var,2)
@@ -714,20 +714,20 @@ end subroutine min_val_2di
 !-----------------------------
 
 subroutine min_val_2df(var, mimnx, mimny, mimv, undef)
-! 2 ѺǾ, ֹ롼
-!-- 2 Ǥ, x  y  1 롼Ƥ, Ǥκͤ1
-!-- Ǽ, Ф1롼Ѥ뤳Ȥ, ΤκͤФ
+! 2 次元配列用最小値, 該当配列要素番号取得ルーチン
+!-- 2 次元版は, x 方向に y 回 1 次元ルーチンを呼び, 各要素の最大値を1次元配列に
+!-- 格納後, その配列に対して1次元ルーチンを作用させることで, 全体の最大値を出す
   implicit none
-  real, intent(in) :: var(:,:)  ! 2 Ǿõ
-  integer, intent(inout) :: mimnx  ! κǾͤ˳ 1 ֹ
-  integer, intent(inout) :: mimny  ! κǾͤ˳ 2 ֹ
-  real, intent(inout) :: mimv  ! κǾ
-  real, intent(in), optional :: undef  ! ̤
-  integer :: nx  !  1 ǤĿ(size ؿǼư׻)
-  integer :: ny  !  2 ǤĿ(size ؿǼư׻)
-  integer :: j  ! 졼ź
-  real :: tmp(size(var,2))  ! 
-  integer :: tmp_num(size(var,2))  ! 
+  real, intent(in) :: var(:,:)  ! 2 次元最小値探索配列
+  integer, intent(inout) :: mimnx  ! 配列内の最小値に該当する第 1 配列要素番号
+  integer, intent(inout) :: mimny  ! 配列内の最小値に該当する第 2 配列要素番号
+  real, intent(inout) :: mimv  ! 配列内の最小値
+  real, intent(in), optional :: undef  ! 未定義値
+  integer :: nx  ! 第 1 要素の配列個数(size 関数で自動計算)
+  integer :: ny  ! 第 2 要素の配列個数(size 関数で自動計算)
+  integer :: j  ! イタレーション用添字
+  real :: tmp(size(var,2))  ! 作業用配列
+  integer :: tmp_num(size(var,2))  ! 作業用配列
 
   nx=size(var,1)
   ny=size(var,2)
@@ -760,20 +760,20 @@ end subroutine min_val_2df
 !-----------------------------
 
 subroutine min_val_2dd(var, mimnx, mimny, mimv, undef)
-! 2 ѺǾ, ֹ롼
-!-- 2 Ǥ, x  y  1 롼Ƥ, Ǥκͤ1
-!-- Ǽ, Ф1롼Ѥ뤳Ȥ, ΤκͤФ
+! 2 次元配列用最小値, 該当配列要素番号取得ルーチン
+!-- 2 次元版は, x 方向に y 回 1 次元ルーチンを呼び, 各要素の最大値を1次元配列に
+!-- 格納後, その配列に対して1次元ルーチンを作用させることで, 全体の最大値を出す
   implicit none
-  double precision, intent(in) :: var(:,:)  ! 2 Ǿõ
-  integer, intent(inout) :: mimnx  ! κǾͤ˳ 1 ֹ
-  integer, intent(inout) :: mimny  ! κǾͤ˳ 2 ֹ
-  double precision, intent(inout) :: mimv  ! κǾ
-  double precision, intent(in), optional :: undef  ! ̤
-  integer :: nx  !  1 ǤĿ(size ؿǼư׻)
-  integer :: ny  !  2 ǤĿ(size ؿǼư׻)
-  integer :: j  ! 졼ź
-  double precision :: tmp(size(var,2))  ! 
-  integer :: tmp_num(size(var,2))  ! 
+  double precision, intent(in) :: var(:,:)  ! 2 次元最小値探索配列
+  integer, intent(inout) :: mimnx  ! 配列内の最小値に該当する第 1 配列要素番号
+  integer, intent(inout) :: mimny  ! 配列内の最小値に該当する第 2 配列要素番号
+  double precision, intent(inout) :: mimv  ! 配列内の最小値
+  double precision, intent(in), optional :: undef  ! 未定義値
+  integer :: nx  ! 第 1 要素の配列個数(size 関数で自動計算)
+  integer :: ny  ! 第 2 要素の配列個数(size 関数で自動計算)
+  integer :: j  ! イタレーション用添字
+  double precision :: tmp(size(var,2))  ! 作業用配列
+  integer :: tmp_num(size(var,2))  ! 作業用配列
 
   nx=size(var,1)
   ny=size(var,2)
@@ -806,21 +806,21 @@ end subroutine min_val_2dd
 !-----------------------------
 
 subroutine min_val_3di(var, mimnx, mimny, mimnz, mimv, undef)
-  ! 3 ѺǾ, ֹ롼
+  ! 3 次元配列用最小値, 該当配列要素番号取得ルーチン
   implicit none
-  integer, intent(in) :: var(:,:,:)  ! 3 Ǿõ
-  integer, intent(inout) :: mimnx  ! κǾͤ˳ 1 ֹ
-  integer, intent(inout) :: mimny  ! κǾͤ˳ 2 ֹ
-  integer, intent(inout) :: mimnz  ! κǾͤ˳ 3 ֹ
-  integer, intent(inout) :: mimv  ! κǾ
-  integer, intent(in), optional :: undef  ! ̤
-  integer :: nx  !  1 ǤĿ(size ؿǼư׻)
-  integer :: ny  !  2 ǤĿ(size ؿǼư׻)
-  integer :: nz  !  3 ǤĿ(size ؿǼư׻)
-  integer :: j  ! 졼ź
-  integer :: tmp(size(var,3))  ! 
-  integer :: tmp_num1(size(var,3))  ! 
-  integer :: tmp_num2(size(var,3))  ! 
+  integer, intent(in) :: var(:,:,:)  ! 3 次元最小値探索配列
+  integer, intent(inout) :: mimnx  ! 配列内の最小値に該当する第 1 配列要素番号
+  integer, intent(inout) :: mimny  ! 配列内の最小値に該当する第 2 配列要素番号
+  integer, intent(inout) :: mimnz  ! 配列内の最小値に該当する第 3 配列要素番号
+  integer, intent(inout) :: mimv  ! 配列内の最小値
+  integer, intent(in), optional :: undef  ! 未定義値
+  integer :: nx  ! 第 1 要素の配列個数(size 関数で自動計算)
+  integer :: ny  ! 第 2 要素の配列個数(size 関数で自動計算)
+  integer :: nz  ! 第 3 要素の配列個数(size 関数で自動計算)
+  integer :: j  ! イタレーション用添字
+  integer :: tmp(size(var,3))  ! 作業用配列
+  integer :: tmp_num1(size(var,3))  ! 作業用配列
+  integer :: tmp_num2(size(var,3))  ! 作業用配列
 
   nx=size(var,1)
   ny=size(var,2)
@@ -857,21 +857,21 @@ end subroutine min_val_3di
 !-----------------------------
 
 subroutine min_val_3df(var, mimnx, mimny, mimnz, mimv, undef)
-  ! 3 ѺǾ, ֹ롼
+  ! 3 次元配列用最小値, 該当配列要素番号取得ルーチン
   implicit none
-  real, intent(in) :: var(:,:,:)  ! 3 Ǿõ
-  integer, intent(inout) :: mimnx  ! κǾͤ˳ 1 ֹ
-  integer, intent(inout) :: mimny  ! κǾͤ˳ 2 ֹ
-  integer, intent(inout) :: mimnz  ! κǾͤ˳ 3 ֹ
-  real, intent(inout) :: mimv  ! κǾ
-  real, intent(in), optional :: undef  ! ̤
-  integer :: nx  !  1 ǤĿ(size ؿǼư׻)
-  integer :: ny  !  2 ǤĿ(size ؿǼư׻)
-  integer :: nz  !  3 ǤĿ(size ؿǼư׻)
-  integer :: j  ! 졼ź
-  real :: tmp(size(var,3))  ! 
-  integer :: tmp_num1(size(var,3))  ! 
-  integer :: tmp_num2(size(var,3))  ! 
+  real, intent(in) :: var(:,:,:)  ! 3 次元最小値探索配列
+  integer, intent(inout) :: mimnx  ! 配列内の最小値に該当する第 1 配列要素番号
+  integer, intent(inout) :: mimny  ! 配列内の最小値に該当する第 2 配列要素番号
+  integer, intent(inout) :: mimnz  ! 配列内の最小値に該当する第 3 配列要素番号
+  real, intent(inout) :: mimv  ! 配列内の最小値
+  real, intent(in), optional :: undef  ! 未定義値
+  integer :: nx  ! 第 1 要素の配列個数(size 関数で自動計算)
+  integer :: ny  ! 第 2 要素の配列個数(size 関数で自動計算)
+  integer :: nz  ! 第 3 要素の配列個数(size 関数で自動計算)
+  integer :: j  ! イタレーション用添字
+  real :: tmp(size(var,3))  ! 作業用配列
+  integer :: tmp_num1(size(var,3))  ! 作業用配列
+  integer :: tmp_num2(size(var,3))  ! 作業用配列
 
   nx=size(var,1)
   ny=size(var,2)
@@ -908,21 +908,21 @@ end subroutine min_val_3df
 !-----------------------------
 
 subroutine min_val_3dd(var, mimnx, mimny, mimnz, mimv, undef)
-  ! 3 ѺǾ, ֹ롼
+  ! 3 次元配列用最小値, 該当配列要素番号取得ルーチン
   implicit none
-  double precision, intent(in) :: var(:,:,:)  ! 3 Ǿõ
-  integer, intent(inout) :: mimnx  ! κǾͤ˳ 1 ֹ
-  integer, intent(inout) :: mimny  ! κǾͤ˳ 2 ֹ
-  integer, intent(inout) :: mimnz  ! κǾͤ˳ 3 ֹ
-  double precision, intent(inout) :: mimv  ! κǾ
-  double precision, intent(in), optional :: undef  ! ̤
-  integer :: nx  !  1 ǤĿ(size ؿǼư׻)
-  integer :: ny  !  2 ǤĿ(size ؿǼư׻)
-  integer :: nz  !  3 ǤĿ(size ؿǼư׻)
-  integer :: j  ! 졼ź
-  double precision :: tmp(size(var,3))  ! 
-  integer :: tmp_num1(size(var,3))  ! 
-  integer :: tmp_num2(size(var,3))  ! 
+  double precision, intent(in) :: var(:,:,:)  ! 3 次元最小値探索配列
+  integer, intent(inout) :: mimnx  ! 配列内の最小値に該当する第 1 配列要素番号
+  integer, intent(inout) :: mimny  ! 配列内の最小値に該当する第 2 配列要素番号
+  integer, intent(inout) :: mimnz  ! 配列内の最小値に該当する第 3 配列要素番号
+  double precision, intent(inout) :: mimv  ! 配列内の最小値
+  double precision, intent(in), optional :: undef  ! 未定義値
+  integer :: nx  ! 第 1 要素の配列個数(size 関数で自動計算)
+  integer :: ny  ! 第 2 要素の配列個数(size 関数で自動計算)
+  integer :: nz  ! 第 3 要素の配列個数(size 関数で自動計算)
+  integer :: j  ! イタレーション用添字
+  double precision :: tmp(size(var,3))  ! 作業用配列
+  integer :: tmp_num1(size(var,3))  ! 作業用配列
+  integer :: tmp_num2(size(var,3))  ! 作業用配列
 
   nx=size(var,1)
   ny=size(var,2)
