@@ -302,17 +302,22 @@ real function CAPE( tmp_p, tmp_z, tmp_qv, tmp_t, z_ref, undeff, opt, copt, dl )
                                          ! 2 = LFC から上端まで積算して値を返す.
                                          ! これは, データの上端が LNB 以下の
                                          ! データを処理する場合の措置.
+                                         ! copt = 2 の場合, かつデータ上端が
+                                         ! LNB 以下の場合, CAPE
+                                         ! は符号をつけて返される.
   integer, intent(in), optional :: dl    ! デバッグレベル
   integer :: nx, i, iz_LFC, iz_LNB, option, calc_opt, iundef
   real :: PLFC, TLFC, PLNB, ZLFC, ZLNB
   real :: tmp(size(tmp_p)), t_par(size(tmp_p))
   real :: inv_tmp(size(tmp_p)), inv_p(size(tmp_p))
   real :: undef
+  logical :: no_LNB
 
   t_par=0.0
   iundef=0
 
   nx=size(tmp_p)
+  no_LNB=.false.
 
   if(present(undeff))then
      undef=undeff
@@ -328,6 +333,10 @@ real function CAPE( tmp_p, tmp_z, tmp_qv, tmp_t, z_ref, undeff, opt, copt, dl )
 
   if(present(copt))then
      calc_opt=copt
+     if(calc_opt==2)then
+        write(*,*) "*** MESSAGE (thermo_advanced_function:CAPE) ***"
+        write(*,*) "A potential value to the maximum height is returned in CAPE."
+     end if
   else
      calc_opt=1
   end if
@@ -354,6 +363,7 @@ real function CAPE( tmp_p, tmp_z, tmp_qv, tmp_t, z_ref, undeff, opt, copt, dl )
            iz_LFC=iundef
         end if
         iz_LNB=nx
+        no_LNB=.true.
      else
         iz_LFC=iundef
         iz_LNB=iundef
@@ -396,6 +406,10 @@ real function CAPE( tmp_p, tmp_z, tmp_qv, tmp_t, z_ref, undeff, opt, copt, dl )
 
         CAPE=CAPE*Rd
 
+        if(no_LNB.eqv..true.)then  ! データ上端高度が LNB 以下の場合
+           CAPE=-CAPE
+        end if
+
      else
 
         CAPE=undef
@@ -505,7 +519,8 @@ end function
 !-----------------------------------------------------
 !-----------------------------------------------------
 
-real function CIN( tmp_p, tmp_z, tmp_qv, tmp_t, z_ref, undeff, dl )
+real function CIN( tmp_p, tmp_z, tmp_qv, tmp_t, z_ref, undeff,  &
+  &                nega_force, dl )
 ! 対流抑制エネルギー (Convective INhibitation energy) を計算する.
   use Thermo_Const
   implicit none
@@ -515,12 +530,17 @@ real function CIN( tmp_p, tmp_z, tmp_qv, tmp_t, z_ref, undeff, dl )
   real, intent(in) :: tmp_t(size(tmp_p))  ! 温度 [K]
   real, intent(in) :: z_ref  ! パーセルを持ち上げる基準高度 [m]
   real, intent(in), optional :: undeff
+  logical, intent(in), optional :: nega_force  ! 温度差が負になる高度のみに限定して積分する
+                                               ! .true. = 負高度のみ積分する,
+                                               ! .false. = 正高度も積分する.
+                                               ! デフォルト = .false.
   integer, intent(in), optional :: dl  ! デバッグレベル
   integer :: nx, i, iz_LFC, iz_ref, iz_LCL, iundef
   real :: PLFC, TLFC, ZLFC, PLCL, ZLCL, TLCL, p_ref, T_ref, qv_ref
   real :: tmp(size(tmp_p)), t_par(size(tmp_p))
   real :: inv_tmp(size(tmp_p)), inv_p(size(tmp_p))
   real :: undef
+  logical :: n_flag
 
   t_par=0.0
   iundef=0
@@ -533,6 +553,16 @@ real function CIN( tmp_p, tmp_z, tmp_qv, tmp_t, z_ref, undeff, dl )
      undef=-999.0
   end if
 
+  if(present(nega_force))then
+     n_flag=nega_force
+     if(n_flag.eqv..true.)then
+        write(*,*) "*** MESSAGE (Thermo_Advanced_Function: CIN) ***"
+        write(*,*) "*** Layers with the positive values of (Tp - Ta) are forced to zero."
+     end if
+  else
+     n_flag=.false.
+  end if
+
 !-- z_ref を基準とした, LCL, LFC での温度, 高度, 圧力の計算
 
 !-- LFC 高度の変数計算
@@ -619,6 +649,15 @@ real function CIN( tmp_p, tmp_z, tmp_qv, tmp_t, z_ref, undeff, dl )
            inv_p(i)=tmp_p(nx-i+1)
         end do
 
+!-- 温度差が負領域のみ積分する (= 正領域はゼロに強制).
+        if(n_flag.eqv..true.)then
+           do i=1,nx
+              if(inv_tmp(i)>0.0)then
+                 inv_tmp(i)=0.0
+              end if
+           end do
+        end if
+
         call rectangle_int( inv_p, inv_tmp, PLFC, p_ref, CIN, undef )
 
         CIN=CIN*Rd
