@@ -863,7 +863,7 @@ real function hypsometric_form(p,z,T,z_t, dl)  ! 高度と気圧を与えてあ
   real, intent(in) :: T  ! 基準点での温度 [K]
   real, intent(in), optional :: z_t  ! 求める高度 [m] : デフォルトでは 0 m.
   integer, intent(in), optional :: dl  ! デバッグレベル
-  real, parameter :: gam = 6.5e-3  ! 標準大気の温度減率 [K/m]
+  real, parameter :: gam = -6.5e-3  ! 標準大気の温度減率 [K/m]
   real :: z_calc, p_tmp
 
 !write(*,*) "hypsometric, g=", g
@@ -874,7 +874,7 @@ real function hypsometric_form(p,z,T,z_t, dl)  ! 高度と気圧を与えてあ
      z_calc=0.0
   end if
 
-  p_tmp=p*((T+gam*z)/(T+gam*z_calc))**(g/(gam*Rd))
+  p_tmp=p*(T/(T+gam*(z_calc-z)))**(g/(gam*Rd))
   hypsometric_form=p_tmp
 
   if(present(dl))then
@@ -898,7 +898,7 @@ real function z_hypsometric_form(p,z,T,p_t, dl)
   real, intent(in) :: T  ! 基準点での温度 [K]
   real, intent(in) :: p_t  ! 求める圧力 [Pa]
   integer, intent(in), optional :: dl  ! デバッグレベル
-  real, parameter :: gam = 6.5e-3  ! 標準大気の温度減率 [K/m]
+  real, parameter :: gam = -6.5e-3  ! 標準大気の温度減率 [K/m]
   real :: alpha
 
   alpha=Rd*gam/g
